<?php

// Page Title Controller
$title = ['Jahresbericht 2017'];

if (isset($report)) {
	$title[] = $report['title'][$lang];
} elseif ($path === '/report') {
	$title[] = 'Themen';
} elseif ($path === '/report/monuments') {
	$title[] = 'Wikipedia Loves Monuments';
} elseif ($path === '/finance') {
	$title[] = 'Finanzreport';
} elseif ($path === '/finance/assn') {
	$title[] = 'Finanzen WMDE e.V.';
} elseif ($path === '/finance/fund') {
	$title[] = 'Finanzen Fördergesellschaft';
}

?>
<!DOCTYPE html>
<html lang="de">
<head>
	<meta charset="UTF-8">
	<title><?php echo implode(' – ', array_reverse($title)) ?> – Wikimedia Deutschland e. V.</title>

	<?php
	// mark up the canonical page and any other variants; use complete url
	// in this case, pages in default language are duplicated; prefer the prefixed '/de' paths
	// see https://support.google.com/webmasters/answer/139066?visit_id=0-636295122699147333-3497274728&rd=1#2
	?>
	<link rel="canonical" href="<?= trim(trim(PROJECT_DOMAIN, '/') . '/de/' . trim($path, '/'), '/') ?>">

<?php if ($isCanonical): ?>
	<?php
	// each language page should identify different language versions, including itself
	// no need to list hreflang on non-canonical - in this case, unprefixed - urls
	// see https://support.google.com/webmasters/answer/189077
	?>
	<link rel="alternate" hreflang="de" href="<?= trim(trim(PROJECT_DOMAIN, '/') . '/de/' . trim($path, '/'), '/') ?>">
	<link rel="alternate" hreflang="en" href="<?= trim(trim(PROJECT_DOMAIN, '/') . '/en/' . trim($path, '/'), '/') ?>">
<?php endif ?>

	<link rel="icon" href="/assets/ico/app.png?v=1+d14caaf">
	<link rel="stylesheet" href="/assets/css/normalize.css?v=1+d14caaf">
	<link rel="stylesheet" href="/assets/css/base.css?v=1+d14caaf">

	<meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">
	<meta name="viewport" content="user-scalable=no, width=device-width, initial-scale=1, maximum-scale=1">

	<script src="/assets/js/compat/core.js?v=1+d14caaf"></script>
	<script src="/assets/js/require.js?v=1+d14caaf"></script>
	<script src="/assets/js/base.js?v=1+d14caaf"></script>
	<?php foreach ($scripts as $script): ?>
		<script async src="/assets/js/<?= $script ?>.js?v=1+d14caaf"></script>
	<?php endforeach ?>
</head>
<body>

<!-- Piwik -->
<script type="text/javascript">
	var _paq = _paq || [];
	_paq.push(["setDomains", ["*.2017.wikimedia.de"]]);
	_paq.push(['trackPageView']);
	_paq.push(['enableLinkTracking']);
	(function() {
		var u="//stats.wikimedia.de/";
		_paq.push(['setTrackerUrl', u+'piwik.php']);
		_paq.push(['setSiteId', '8']);
		var d=document, g=d.createElement('script'),
		s=d.getElementsByTagName('script')[0];
		g.type='text/javascript'; g.async=true; g.defer=true;
		g.src=u+'piwik.js'; s.parentNode.insertBefore(g,s);
	})();
</script>
<noscript>
	<p>
		<img src="https://stats.wikimedia.de/piwik.php?idsite=8" style="border:0;" alt="" />
	</p>
</noscript>
<!-- End Piwik Code -->

<?php if ($hasBlackHeader): ?>
<div class="cp real-logo-black real-logo">
<?php else: ?>
<div class="cp real-logo-white real-logo">
<?php endif ?>
	<a class="logo main-header__logo image-replace logo--s" href="<?= $url('/', $lang) ?>">Wikimedia Deutschland</a>
</div>
<div class="mn-container cp">
	<div class="mn-close"></div>
	<ul class="mn__list">
		<li><a class="mn__link" href="<?= $url('report', $lang) ?>">Themen</a></li>
		<li><a class="mn__link" href="<?= $url('finance', $lang) ?>">Finanzen</a></li>
	</ul>
	<div class="mn__mini-nav">
		<a class="t--epsilon lang-switch" href="<?= $switchLanguageFromUrl($lang) ?>">English Site</a>
		<a class="pdf-download t--epsilon" download href="/assets/doc/jahresbericht_2017_de.pdf">PDF</a>
		<a class="t--epsilon" href="https://spenden.wikimedia.de/apply-for-membership?piwik_campaign=jb2017&piwik_kwd=mitglieds_btn" target="new">Mitglied werden</a>
	</div>
</div>

<header
	<?php if ($hasBlackHeader): ?>
		class="main-header main-header--black"
	<?php else: ?>
		class="main-header main-header--white"
	<?php endif ?>
>
	<div class="cp">
		<div class="limit--l clearfix">
			<a class="logo main-header__logo image-replace logo--l" href="<?= $url('/', $lang) ?>">Wikimedia Deutschland</a>
			<nav class="nav main-header__nav">
				<ul class="nav__list">
					<li>
						<a
							class="nav__link<?= (preg_match('#^/report.*$#', $path) ? ' active' : '')?>"
							href="<?= $url('report', $lang) ?>"
						>
							Themen
						</a>
					</li>
					<li>
						<a
							class="nav__link<?= (preg_match('#^/finance.*$#', $path) ? ' active' : '')?>"
							href="<?= $url('finance', $lang) ?>"
						>
							Finanzen
						</a>
					</li>
				</ul>
				<main class="nav__list--upper">
					<a class="lang-switch" href="<?= $switchLanguageFromUrl($lang) ?>">English Site</a>
					<a class="pdf-download" download href="/assets/doc/jahresbericht_2017_de.pdf">PDF</a>
					<a href="https://spenden.wikimedia.de/apply-for-membership?piwik_campaign=jb2017&piwik_kwd=mitglieds_btn" target="new">Mitglied werden</a>
				</main>
			</nav>
			<nav class="nav mobile__nav">
				<div class="nav__link mn-trigger">Menü</div>
			</nav>
		</div>
	</div>
</header>
